# roughviz

![roughviz](https://user-images.githubusercontent.com/7835634/69475723-6bce0080-0df6-11ea-8f36-82128cc108ac.jpg)

roughviz is a python visualization library for creating sketchy/hand-drawn styled charts.

[![forthebadge](https://forthebadge.com/images/badges/built-with-love.svg)](https://github.com/hannansatopay)

### Available Charts
<ul>
  <li>Bar (<code>roughviz.bar</code>) </li>
  <li>Horizontal Bar (<code>roughviz.barh</code>) </li>
  <li>Pie (<code>roughviz.pie</code>) </li>
  <li>Donut (<code>roughviz.donut</code>) </li>
  <li>Stacked Bar (<code>roughviz.stackedbar</code>) </li>
</ul>

### Installation
[![PyPI](https://img.shields.io/pypi/v/roughviz?color=dark%20green&style=for-the-badge)](https://pypi.org/project/roughviz/)
[![PyPI - Downloads](https://img.shields.io/pypi/dm/roughviz?color=dark%20green&style=for-the-badge)](https://pypi.org/project/roughviz/)
```
pip install roughviz
```

### Usage

[![badge](https://camo.githubusercontent.com/bfeb5472ee3df9b7c63ea3b260dc0c679be90b97/68747470733a2f2f696d672e736869656c64732e696f2f62616467652f72656e6465722d6e627669657765722d6f72616e67652e7376673f636f6c6f72423d66333736323626636f6c6f72413d346434643464)](https://nbviewer.jupyter.org/github/hannansatopay/roughviz/blob/master/roughviz%20example.ipynb)


[![badge](https://camo.githubusercontent.com/52feade06f2fecbf006889a904d221e6a730c194/68747470733a2f2f636f6c61622e72657365617263682e676f6f676c652e636f6d2f6173736574732f636f6c61622d62616467652e737667)](https://colab.research.google.com/github/hannansatopay/roughviz/blob/master/roughviz%20example.ipynb)

### API
The API Documentation is available on: [roughviz wiki](https://github.com/hannansatopay/roughviz/wiki/API)

### Future Plans
- [ ] Exception Handling
- [ ] Add Chart: Histogram
- [ ] Add Chart: Scatter
- [ ] Add Chart: Bubble Chart
- [ ] Add Chart: Line
- [ ] Advance CSS control capabilities

### Based on
<a href="https://github.com/jwilber/roughViz"><img src="https://raw.githubusercontent.com/jwilber/random_data/master/roughViz_Title.png"  width="350" alt="roughViz.js"><a>

### License
[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)

Copyright (c) 2019 Hannan Satopay
